==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AEmptyMethodBody.h <==
// public final class soot.jimple.parser.node.AEmptyMethodBody

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e66d2185f50598db soot_jimple_parser_node_AEmptyMethodBody
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class f2190a022a2f6c71 soot_jimple_parser_node_PMethodBody

// header file dependencies
// @dep_header soot_jimple_parser_node_PMethodBody

#include "soot/jimple/parser/node/PMethodBody.h"

#ifndef _JC_soot_jimple_parser_node_AEmptyMethodBody_H_
#define _JC_soot_jimple_parser_node_AEmptyMethodBody_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TSemicolon$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_refs	_jc_soot_jimple_parser_node_AEmptyMethodBody$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_nonrefs	_jc_soot_jimple_parser_node_AEmptyMethodBody$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AEmptyMethodBody$refs	_jc_soot_jimple_parser_node_AEmptyMethodBody$refs;
typedef struct _jc_soot_jimple_parser_node_AEmptyMethodBody$nonrefs	_jc_soot_jimple_parser_node_AEmptyMethodBody$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object	_jc_soot_jimple_parser_node_AEmptyMethodBody$object;

typedef const struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vmethods	_jc_soot_jimple_parser_node_AEmptyMethodBody$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vtable	_jc_soot_jimple_parser_node_AEmptyMethodBody$vtable;
typedef const struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vtype	_jc_soot_jimple_parser_node_AEmptyMethodBody$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *);
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$_init$3af37be14d7924a6(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_TSemicolon$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AEmptyMethodBody$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *);
extern struct _jc_soot_jimple_parser_node_TSemicolon$object *_jc_soot_jimple_parser_node_AEmptyMethodBody$method$getSemicolon$48c1669dacccedc7(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *);
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$setSemicolon$3f87c46ec7fc05a2(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_TSemicolon$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AEmptyMethodBody$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$getSemicolon$48c1669dacccedc7;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$setSemicolon$3f87c46ec7fc05a2;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *);
	struct _jc_soot_jimple_parser_node_TSemicolon$object	*(*getSemicolon$48c1669dacccedc7)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setSemicolon$3f87c46ec7fc05a2)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_TSemicolon$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PMethodBody$vmethods	soot_jimple_parser_node_PMethodBody;
	_jc_soot_jimple_parser_node_AEmptyMethodBody$vmethods	soot_jimple_parser_node_AEmptyMethodBody;
};

// Vtype
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AEmptyMethodBody$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_refs {
	struct _jc_soot_jimple_parser_node_TSemicolon$object	*__5fsemicolon__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$refs {
    _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_refs	soot_jimple_parser_node_AEmptyMethodBody;
    _jc_soot_jimple_parser_node_PMethodBody$sub_refs	soot_jimple_parser_node_PMethodBody;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PMethodBody$sub_nonrefs	soot_jimple_parser_node_PMethodBody;
    _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_nonrefs	soot_jimple_parser_node_AEmptyMethodBody;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object {
	_jc_soot_jimple_parser_node_AEmptyMethodBody$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AEmptyMethodBody$vtype	*vtype;
	_jc_soot_jimple_parser_node_AEmptyMethodBody$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AEmptyMethodBody$vtype _jc_soot_jimple_parser_node_AEmptyMethodBody$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AEmptyMethodBody, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AEmptyMethodBody$class_object;

#endif	/* _JC_soot_jimple_parser_node_AEmptyMethodBody_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AEmptyMethodBody.h <==
// public final class soot.jimple.parser.node.AEmptyMethodBody

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e66d2185f50598db soot_jimple_parser_node_AEmptyMethodBody
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class f2190a022a2f6c71 soot_jimple_parser_node_PMethodBody

// header file dependencies
// @dep_header soot_jimple_parser_node_PMethodBody

#include "soot/jimple/parser/node/PMethodBody.h"

#ifndef _JC_soot_jimple_parser_node_AEmptyMethodBody_H_
#define _JC_soot_jimple_parser_node_AEmptyMethodBody_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TSemicolon$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_refs	_jc_soot_jimple_parser_node_AEmptyMethodBody$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_nonrefs	_jc_soot_jimple_parser_node_AEmptyMethodBody$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AEmptyMethodBody$refs	_jc_soot_jimple_parser_node_AEmptyMethodBody$refs;
typedef struct _jc_soot_jimple_parser_node_AEmptyMethodBody$nonrefs	_jc_soot_jimple_parser_node_AEmptyMethodBody$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object	_jc_soot_jimple_parser_node_AEmptyMethodBody$object;

typedef const struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vmethods	_jc_soot_jimple_parser_node_AEmptyMethodBody$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vtable	_jc_soot_jimple_parser_node_AEmptyMethodBody$vtable;
typedef const struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vtype	_jc_soot_jimple_parser_node_AEmptyMethodBody$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$_init$3af37be14d7924a6(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_TSemicolon$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AEmptyMethodBody$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TSemicolon$object *_jc_soot_jimple_parser_node_AEmptyMethodBody$method$getSemicolon$48c1669dacccedc7(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AEmptyMethodBody$method$setSemicolon$3f87c46ec7fc05a2(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_TSemicolon$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AEmptyMethodBody$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$getSemicolon$48c1669dacccedc7;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$setSemicolon$3f87c46ec7fc05a2;
extern _jc_method _jc_soot_jimple_parser_node_AEmptyMethodBody$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TSemicolon$object	*(*getSemicolon$48c1669dacccedc7)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setSemicolon$3f87c46ec7fc05a2)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *, struct _jc_soot_jimple_parser_node_TSemicolon$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PMethodBody$vmethods	soot_jimple_parser_node_PMethodBody;
	_jc_soot_jimple_parser_node_AEmptyMethodBody$vmethods	soot_jimple_parser_node_AEmptyMethodBody;
};

// Vtype
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AEmptyMethodBody$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_refs {
	struct _jc_soot_jimple_parser_node_TSemicolon$object	*__5fsemicolon__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$refs {
    _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_refs	soot_jimple_parser_node_AEmptyMethodBody;
    _jc_soot_jimple_parser_node_PMethodBody$sub_refs	soot_jimple_parser_node_PMethodBody;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PMethodBody$sub_nonrefs	soot_jimple_parser_node_PMethodBody;
    _jc_soot_jimple_parser_node_AEmptyMethodBody$sub_nonrefs	soot_jimple_parser_node_AEmptyMethodBody;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AEmptyMethodBody$object {
	_jc_soot_jimple_parser_node_AEmptyMethodBody$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AEmptyMethodBody$vtype	*vtype;
	_jc_soot_jimple_parser_node_AEmptyMethodBody$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AEmptyMethodBody$vtype _jc_soot_jimple_parser_node_AEmptyMethodBody$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AEmptyMethodBody, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AEmptyMethodBody$class_object;

#endif	/* _JC_soot_jimple_parser_node_AEmptyMethodBody_H_ */
